# EIDA Consistency Report: `ETH`

- Seed: `332194`
- Time: `2025-09-08T16:53:37.582269+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `19`
- Inconsistent: `1`
- Score: **95.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `1`

## Dataselect Response Types
- **NoTrace**: `6`
- **SingleTrace**: `14`

---

## Detailed Results
### `CH.SCHE..HGZ`
- Window: `2005-02-12T01:15:22 → 2005-02-12T01:25:22`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `CH.SDAS..HGZ`
- Window: `1999-01-24T11:13:49 → 1999-01-24T11:23:49`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `XA.BHW16..HHE`
- Window: `2014-01-01T10:33:40 → 2014-01-01T10:43:40`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `CH.WALHA..HHE`
- Window: `2022-04-11T06:23:33 → 2022-04-11T06:33:33`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `CH.SZIM..HGZ`
- Window: `2025-02-26T06:53:05 → 2025-02-26T07:03:05`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `YL.R03..EHZ`
- Window: `2000-12-24T13:21:13 → 2000-12-24T13:31:13`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `CH.SKEH..HGE`
- Window: `1995-09-30T21:39:54 → 1995-09-30T21:49:54`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `YL.R04..EHE`
- Window: `2000-09-06T04:54:50 → 2000-09-06T05:04:50`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XT.AAE43..HHN`
- Window: `2015-01-01T03:49:59 → 2015-01-01T03:59:59`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `CH.METMA..HHZ`
- Window: `2017-10-22T09:55:49 → 2017-10-22T10:05:49`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z9.MA12..HHZ`
- Window: `2017-03-22T22:52:22 → 2017-03-22T23:02:22`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `CH.SLAE..HGE`
- Window: `2014-01-04T05:25:41 → 2014-01-04T05:35:41`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `YL.A01..EHN`
- Window: `2000-10-15T22:10:54 → 2000-10-15T22:20:54`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `8X.CA08A..HHZ`
- Window: `2016-12-28T11:04:10 → 2016-12-28T11:14:10`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z9.MA6..HHN`
- Window: `2017-01-04T01:23:47 → 2017-01-04T01:33:47`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `YL.I01..EHN`
- Window: `2000-09-19T12:46:02 → 2000-09-19T12:56:02`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `S.COLEY..EHZ`
- Window: `2025-07-25T03:34:50 → 2025-07-25T03:44:50`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `CH.EMMET..HHZ`
- Window: `2025-06-07T12:17:40 → 2025-06-07T12:27:40`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `CH.PANIX..HHE`
- Window: `2017-05-21T20:19:03 → 2017-05-21T20:29:03`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `CH.STSP..HGN`
- Window: `2012-05-02T11:50:57 → 2012-05-02T12:00:57`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`
